package com.jz.dm.mall.moduls.controller.company;

import com.aliyuncs.http.HttpRequest;
import com.jz.common.entity.Department;
import com.jz.common.utils.Result;
import com.jz.dm.mall.moduls.controller.company.bean.CompanyAddReq;
import com.jz.dm.mall.moduls.controller.company.bean.CompanyUpdateReq;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.dm.mall.moduls.service.CompanyAuthService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;

import javax.servlet.http.HttpServletRequest;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.mall.moduls.controller.company
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: CompanyAuthController
 * @USER: key
 * @DATE: 2020-12-2/16:33
 * @DAY_NAME_SHORT: 周三
 * @Description:
 **/
@RestController
@RequestMapping("/companyAuth")
@Api(tags = "企业认证controller")
public class CompanyAuthController {

    @Autowired
    private CompanyAuthService companyAuthService;


    /**
    * @Description: 添加企业认证信息
    * @Author: Mr.zhang
    * @Date: 2020-12-2
    */
    @PostMapping("/add")
    @ApiOperation(value = "企业信息提交")
    public Mono<Result> addCompanyAuth(@RequestBody @Validated CompanyAddReq req) {
        return Mono.fromSupplier(() -> companyAuthService.addCompanyData(req));
    }

    /**
     * @Description: 企业认证信息查询
     * @Author: Mr.zhang
     * @Date: 2020-12-2
     */
    @GetMapping("/findCompany")
    @ApiOperation(value = "企业认证信息查询")
    public Mono<Result> selectCompany(@RequestParam(value = "type") String type) {
        return Mono.fromSupplier(() ->{
                //TODO 获取当前登录用户
                //httpRequest.getSession().getServletContext().getAttribute("customer_id");
           return Result.ok(companyAuthService.selectCompany(type));
        });
    }
    /**
     * @Description: 企业认证信息更新
     * @Author: Mr.zhang
     * @Date: 2020-12-2
     */
    @GetMapping("/updateCompany")
    @ApiOperation(value = "企业认证信息更新")
    public Mono<Result> updateCompany(@RequestBody @Validated CompanyUpdateReq req) {
        return Mono.fromSupplier(() ->companyAuthService.updateCompanyInfo(req));
    }
    /**
     * @Description: 企业认证信息更新
     * @Author: Mr.zhang
     * @Date: 2020-12-2
     */
    @GetMapping("/checkCompany")
    @ApiOperation(value = "企业认证信息校验")
    public Mono<Result> checkCompany() {
        return Mono.fromSupplier(() ->companyAuthService.checkCompanyInfo());
    }
}
