package com.jz.dm.mall.moduls.service.impl;

import com.jz.common.enums.AuditStatusEnum;
import com.jz.common.utils.Result;
import com.jz.dm.mall.moduls.controller.finance.bean.FinanceCashOutDto;
import com.jz.dm.mall.moduls.controller.finance.bean.FinanceCashOutRequest;
import com.jz.dm.mall.moduls.controller.finance.bean.FinanceCustomerAssetsDto;
import com.jz.dm.mall.moduls.controller.finance.bean.FinanceCustomerBalanceRequest;
import com.jz.dm.mall.moduls.entity.FinanceCashOut;
import com.jz.dm.mall.moduls.entity.FinanceCustomerAssets;
import com.jz.dm.mall.moduls.entity.FinanceCustomerBalance;
import com.jz.dm.mall.moduls.mapper.FinanceCustomerAssetsDao;
import com.jz.dm.mall.moduls.mapper.FinanceTradeFlowDao;
import com.jz.dm.mall.moduls.service.FinanceTradeFlowService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 企业客户交易流水(TFinanceTradeFlow)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:39
 */
@Service("financeTradeFlowService")
@Transactional
public class FinanceTradeFlowServiceImpl implements FinanceTradeFlowService {

    @Autowired
    private FinanceTradeFlowDao financeTradeFlowDao;

    @Autowired
    private FinanceCustomerAssetsDao financeCustomerAssetsDao;

    @Override
    public FinanceCustomerAssetsDto queryAccountMoneyByMap(Map map) throws Exception {
        return financeTradeFlowDao.queryAccountMoneyByMap(map);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean uptAccountMoney(FinanceCustomerBalanceRequest customerBalanceRequest) throws Exception {
        //1.充值记录表中加数据
        FinanceCustomerBalance financeCustomerBalance = new FinanceCustomerBalance();
        financeCustomerBalance.setAssetsId(customerBalanceRequest.getAssetsId());//企业资产id
        financeCustomerBalance.setBalanceMoney(customerBalanceRequest.getBalanceMoney()); //充值金额
        //financeCustomerBalance.setCrePerson();
        financeCustomerBalance.setCreTime(new Date());
        financeCustomerBalance.setAuditStatus("01"); //待审核
        financeCustomerBalance.setRemark(customerBalanceRequest.getRemark()); //备注
        int len = financeCustomerAssetsDao.addCoustomerCzMoney(financeCustomerBalance);
       /* //2.更新企业资产账户
        int len = financeCustomerAssetsDao.uptAccountMoney(financeCustomerBalanceRequest);
        //3.在流水记录中添加数据*/
        return len > 0;
    }

    @Override
    public FinanceCashOutDto getCashOutAuditStutas(Map map) throws Exception {
        //查询当前企业账户，存在的提现未审核的记录
        BigDecimal auditMoney = new BigDecimal("0");
        List<FinanceCashOutDto> list = financeTradeFlowDao.getCashOutAuditStutas(map);
        if (list.size() > 0 && list != null) {
            for (FinanceCashOutDto dto : list) {
                auditMoney = auditMoney.add(new BigDecimal(dto.getCashOutMoney().toString())); //累加提现待审核 金额
            }
        }
        FinanceCashOutDto returnDto = new FinanceCashOutDto();
        returnDto.setCashOutMoney(auditMoney);
        return returnDto;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result<Object> addCashOutMoney(FinanceCashOutRequest financeCashOutRequest) throws Exception {
        Result<Object> result = new Result<>();
        Long assetId = financeCashOutRequest.getAssetsId(); // 企业资产id
        BigDecimal cashOutMoney = new BigDecimal(financeCashOutRequest.getCashOutMoney().toString()); //提现金额

        FinanceCashOut financeCashOut = new FinanceCashOut();
        BeanUtils.copyProperties(financeCashOutRequest, financeCashOut);
        financeCashOut.setCreTime(new Date()); //创建时间
        financeCashOut.setCashOutTime(new Date()); //提现时间
        financeCashOut.setAuditStatus(AuditStatusEnum.DSH.getValue()); //待审核
        //financeCashOut.setCrePerson();
        //添加一条提现记录
        int len = financeTradeFlowDao.addCashOutMoney(financeCashOut);

        if (len == 0) {
            result.setMessage("提交失败！");
            result.setCode(500);
            return result;
        }
        // 查询 当前企业 可用余额 冻结金额
        Map map = new HashMap();
        map.put("assetId", assetId);
        FinanceCustomerAssetsDto dto = financeTradeFlowDao.queryAccountMoneyByMap(map);
        BigDecimal useMoney = new BigDecimal(dto.getUseMoney().toString()); //可用金额
        if (useMoney != null && cashOutMoney != null) {
            if (useMoney.compareTo(cashOutMoney) > -1) { //可用大于等于提现
                useMoney = useMoney.subtract(cashOutMoney); //可用 减去 提现

                BigDecimal djMoney = new BigDecimal(dto.getFrozenMoney().toString()); //冻结金额
                djMoney = djMoney.add(cashOutMoney); //累计冻结金额

                //修改企业资产 金额
                FinanceCustomerAssets assets = new FinanceCustomerAssets();
                assets.setUptTime(new Date());
                //assets.setUptPerson();
                assets.setUseMoney(useMoney);
                assets.setFrozenMoney(djMoney);
                assets.setAssetsId(assetId);
                int lens = financeCustomerAssetsDao.uptAccountMoney(assets);
                if (lens == 0) {
                    result.setMessage("提交失败！");
                    result.setCode(500);
                    return result;
                }
            } else {
                result.setMessage("提交失败！");
                result.setCode(500);
                return result;
            }
        }
        return result;
    }
}